import pygame
from unittest import mock
from pytest_devlife import util
from pytest_devlife.fixtures import mockgame
import inspect
try:
    import jogo
except ImportError:
    jogo = None


def test_retangulo_fora_a_esquerda():
    util.function_exists_in_module(jogo, 'colisao_rect')
    rects = [
        [0, 30, 90, 100],
        [90, 100, 5, 60],
        [70, 170, 20, 10],
        [0, 200, 110, 30]
    ]

    base_rect = [100, 150, 50, 30]
    for r in rects:
        assert not jogo.colisao_rect(r, base_rect), f'Não tem colisão entre {r} e {base_rect}'


def test_retangulo_fora_a_direita():
    util.function_exists_in_module(jogo, 'colisao_rect')
    rects = [
        [160, 30, 90, 100],
        [200, 100, 5, 60],
        [165, 170, 20, 10],
        [170, 200, 110, 30]
    ]

    base_rect = [100, 150, 50, 30]
    for r in rects:
        assert not jogo.colisao_rect(base_rect, r), f'Não tem colisão entre {r} e {base_rect}'


def test_retangulo_fora_no_topo():
    util.function_exists_in_module(jogo, 'colisao_rect')
    rects = [
        [110, 130, 20, 10],
        [130, 110, 20, 5],
    ]

    base_rect = [100, 150, 50, 30]
    for r in rects:
        assert not jogo.colisao_rect(base_rect, r), f'Não tem colisão entre {r} e {base_rect}'


def test_retangulo_fora_abaixo():
    util.function_exists_in_module(jogo, 'colisao_rect')
    rects = [
        [210, 130, 20, 10],
        [230, 110, 20, 45],
    ]

    base_rect = [100, 150, 50, 30]
    for r in rects:
        assert not jogo.colisao_rect(base_rect, r), f'Não tem colisão entre {r} e {base_rect}'


def test_retangulo_um_vertice_dentro():
    util.function_exists_in_module(jogo, 'colisao_rect')
    rects = [
        [90, 130, 20, 30],
        [110, 145, 60, 15],
        [90, 160, 25, 40],
        [120, 170, 50, 30]
    ]

    base_rect = [100, 150, 50, 30]
    for r in rects:
        assert jogo.colisao_rect(base_rect, r), f'Tem colisão entre {r} e {base_rect}'


def test_retangulo_inteiro_dentro():
    util.function_exists_in_module(jogo, 'colisao_rect')

    r1 = [30, 50, 100, 120]
    r2 = [40, 60, 10, 10]

    assert jogo.colisao_rect(r1, r2), f'Tem colisão entre {r1} e {r2}'


def test_retangulo_colisao_em_forma_de_cruz():
    util.function_exists_in_module(jogo, 'colisao_rect')

    r1 = [30, 50, 100, 30]
    r2 = [50, 20, 20, 100]

    assert jogo.colisao_rect(r1, r2), f'Tem colisão entre {r1} e {r2}'
